@@ -12,4 +12,4 @@ COUNT=$(cat /proc/cpuinfo | grep 'model name' | sed -e 's/.*: //' | wc -l)
 echo "number of detected CPUs =" $COUNT
 
 #cppcheck -j $COUNT --force --inline-suppr --enable=warning . 2>errors.txt
-cppcheck -j $COUNT --force --enable=style . 2>errors.txt
\ No newline at end of file
+cppcheck -j $COUNT --force --enable=style . 2>cppreport.txt
\ No newline at end of file
