@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -44,11 +44,7 @@
 #include <exception>
 #include <assert.h>
 
-#include "../icons/line.h"
-#include "../icons/name.h"
-#include "../icons/opensource.h"
-#include "../icons/pump.h"
-
+//
 // #include "htinterface.h"
 // #include "htsstrings.h"
 
@@ -95,7 +91,7 @@ bool writeWIniFile(QIODevice &device, const QSettings::SettingsMap &map)
                     val.remove(val.length() - 1, 1);
                 }
 
-                val.remove("%0d%0a");
+                val.replace("\n", "%0d%0a");
             }
 
             buffer = QString ( "%1=%2\n" ).arg ( it.key(), val );
@@ -147,7 +143,8 @@ bool readWIniFile(QIODevice &device, QSettings::SettingsMap &map)
                     val.remove(val.length() - 1, 1);
                 }
 
-                val.remove("%0d%0a");
+                val.replace("%0d%0a", "\n");
+                //                 val.remove("%0d%0a");
             }
 
             if ( ! key.isEmpty() ) {
@@ -418,19 +415,18 @@ HTTraQt::HTTraQt(QWidget* parent, Qt::WindowFlags flags)
 
     readGUISettings();
 
-    QPixmap line = QPixmap(line_xpm);
-    mainpix = new QPixmap();
-    *mainpix = line.scaled(479, 100);
+    mainpix = new QPixmap(":/icons/line.png");
+    *mainpix = mainpix->scaled(479, 100);
 
     QPainter painterPix(mainpix);
-    painterPix.drawPixmap(25, 5, QPixmap(pump_xpm));
-    painterPix.drawPixmap(122, 78, QPixmap(opensource_xpm));
-    painterPix.drawPixmap(142, 17, QPixmap(name_xpm));
+    painterPix.drawPixmap(25, 5, QPixmap(":/icons/pump.png"));
+    painterPix.drawPixmap(122, 78, QPixmap(":/icons/opensource.png"));
+    painterPix.drawPixmap(142, 17, QPixmap(":/icons/name.png"));
 
     mainicon = new QPixmap(100, 100);
     mainicon->fill(Qt::transparent);
     QPainter painterIcon(mainicon);
-    painterIcon.drawPixmap(25, 5, QPixmap(pump_xpm));
+    painterIcon.drawPixmap(25, 5, QPixmap(":/icons/pump.png"));
 
     programStyleSheet = QString().sprintf("font-size: %dpt", fontSize);
 
@@ -495,12 +491,7 @@ HTTraQt::HTTraQt(QWidget* parent, Qt::WindowFlags flags)
     shell_terminated = 0;
     soft_term_requested = 0;
 
-#if USE_QT_VERSION == 5
-    //     QImage();
-    setWindowIcon(QIcon(QPixmap::fromImage(QImage(*mainicon))));
-#else
     setWindowIcon(QIcon(*mainicon));
-#endif
 
     dModel.setReadOnly(true);
 
@@ -837,7 +828,7 @@ QString HTTraQt::sizeToText(long long int s)
 
 void HTTraQt::onEndMirror()
 {
-    QStringList ext;
+    QStringList ext = (QStringList() << "zip" << "dat" << "ndx");
     QString oldName, oldShort;
     QString newName, newShort;
     long int oldSize = -1;
@@ -845,8 +836,6 @@ void HTTraQt::onEndMirror()
 
     //     endInProgress();
 
-    ext << "zip" << "dat" << "ndx";
-
     QString projectDir;
     projectDir =  currentWorkDir + "/" + currentProject + "/";
 
@@ -1078,14 +1067,7 @@ void HTTraQt::createTrayIcon()
 
     trayIcon->setContextMenu(trayIconMenu);
 
-#if USE_QT_VERSION == 5
-    //     QImage();
-    trayIcon->setIcon(QIcon(QPixmap::fromImage(QImage(*mainicon))));
-#else
     trayIcon->setIcon(QIcon(*mainicon));
-#endif
-
-
 }
 
 
@@ -2518,10 +2500,10 @@ void HTTraQt::closeEvent(QCloseEvent* ce)
 
     writeGUISettings();
 
-//     ce->accept();
-    
+    //     ce->accept();
+
     qApp->quit();
-//     return;
+    //     return;
 }
 
 
