@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -32,7 +32,7 @@ class cTranslator
         bool loadTranslation(const QString fname);
     public:
         static QString translate(int id);
-        static QString engText[500];
+        static QString engText[];
     private:
         QString convertString(const QString &s);
 
@@ -536,7 +536,8 @@ enum TR_CONSTS {
     _OPEN, //491
     _PC_OFF, // 492
     _SHUTDOWN_COUNTER, // 493
-    _MAKE_TRANSLATION // 494
+    _MAKE_TRANSLATION, // 494
+    _BROWS_NAME //495
 };
 
 
