@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -135,8 +135,9 @@ void cOptions::GetProfile(const QString &variName, QString &val)
 
 void cOptions::saveOptions(QSettings *s, bool gl)
 {
-    QString os, st;
+    QString os, st, br;
     GetProfile("BrowserID", st);
+    GetProfile("BrowserName", br);
     GetProfile("osID", os);
 
     if (st.length() > 0) {
@@ -194,7 +195,7 @@ void cOptions::StripControls(QString &st)
     //     st.replace(0x0a, " ");
     //     st.replace(0x0d, " ");
     st.simplified();
-    st.replace("  ", " ");
+    //     st.replace("  ", " ");
 }
 
 
@@ -477,8 +478,9 @@ void cOptions::getOptStruct(httrackp *g_opt)
     }
 
     // user_agent
-    QString os, st;
+    QString os, st, br;
     GetProfile("BrowserID", st);
+    GetProfile("BrowserName", br);
     GetProfile("osID", os);
 
     if (st.length() > 0) {
@@ -957,8 +959,9 @@ QString cOptions::cmdArgumentsOptions(int num)
 
     //     cmdOpt += "#f";  // flush
 
-    QString os;
+    QString os, br;
     GetProfile("BrowserID", st);
+    GetProfile("BrowserName", br);
     GetProfile("osID", os);
 
     if (st.length() > 0) {
@@ -1136,6 +1139,9 @@ void cOptions::initOptions()
     prOptions[ "UserID" ] = (OptStruct) {
         TEXT, "Mozilla/5.0 (X11; U; Linux i686; I; rv:17.0.1) Gecko/20100101 Firefox/17.0.1"
     };
+    prOptions[ "BrowserName" ] = (OptStruct) {
+        TEXT, "Firefox"
+    };
     prOptions[ "BrowserID" ] = (OptStruct) {
         TEXT, "Mozilla/5.0 (%s; rv:17.0.1) Gecko/20100101 Firefox/17.0.1"
     };
@@ -1152,7 +1158,7 @@ void cOptions::initOptions()
         INTEGER, 0
     };
     prOptions[ "Footer" ] = (OptStruct) {
-        TEXT, "<!-- Mirrored from %s%s by HTTraQt Website Copier/1.x [Karbofos 2010-2014] %s -->"
+        TEXT, "<!-- Mirrored from %s%s by HTTraQt Website Copier/1.x [Karbofos 2012-2015] %s -->"
     };
     prOptions[ "Cache" ] = (OptStruct) {
         INTEGER, 1
