@@ -210,7 +210,7 @@ void OptionsDialog::getFromGUI()
             }
 
             case TEXTEDIT: { // this one only for rulez->scanList
-                (*ivec).value = ((QTextEdit*)(*ivec).wg)->toPlainText();
+                (*ivec).value = (((QTextEdit*)(*ivec).wg)->toPlainText()).replace("\n"," ").simplified();
                 break;
             }
 
