@@ -103,7 +103,7 @@ void optionsRulez::setScanRulezToGUI()
 {
     QString st;
     disconnect(rulezForm::scanList, SIGNAL(textChanged()), this, SLOT(setScanRulezToGUI()));
-    st = rulezForm::scanList->toPlainText();
+    st = rulezForm::scanList->toPlainText().replace("\n"," ");
 
     // set the widgets
     for (int i = 0; i < 4; i++) {
@@ -116,7 +116,7 @@ void optionsRulez::setScanRulezToGUI()
 
 void optionsRulez::detectTypeInc(const QString &st, int i)
 {
-    QString editString = scanList->toPlainText();
+//     QString editString = scanList->toPlainText();
     QStringList lst = ext[i].split(" ");
 
     for (QStringList::Iterator j = lst.begin(); j != lst.end(); j++) {
@@ -154,6 +154,7 @@ void optionsRulez::onInc()
         for (QStringList::Iterator i = lst.begin(); i != lst.end(); i++) {
             if (editString.contains(*i) == true) {
                 editString.remove(((*i) + " "));
+		editString.remove(((*i) + "\n"));
             }
         }
     }
@@ -168,7 +169,7 @@ void optionsRulez::onChangeLinks(bool incl)
     QString act;
     QString le = rulezForm::lineEdit356->text();
 
-    if (le == "") {
+    if (le == "" && action != 10) {
         return;
     }
 
@@ -231,10 +232,12 @@ void optionsRulez::onChangeLinks(bool incl)
 
     if (editor.contains("+" + act + " ") == true) {
         editor.remove("+" + act + " ");
+	editor.remove("+" + act + "\n");
     }
 
     if (editor.contains("-" + act + " ") == true) {
         editor.remove("-" + act + " ");
+	editor.remove("-" + act + "\n");
     }
 
     if (incl) {
