@@ -1,8 +1,8 @@
 #ifndef HTTVERSION_H
 #define HTTVERSION_H
 
-#define HTTQTVERSION  "1.4.5"
-#define PROGRAM_DATE  "06 Sep 2015"
+#define HTTQTVERSION  "1.4.6"
+#define PROGRAM_DATE  "13 Nov 2015"
 
 #define USE_QT_VERSION  4
 
